==> hydrogen_0.8.2.orig.tar.gz: hydrogen-0.8.2/hydrogen_gui/LadspaFXSelector.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: LadspaFXSelector.h,v 1.4 2004/01/27 15:21:20 comix Exp $
 *
 */

#ifndef LADSPA_FX_SELECTOR_H
#define LADSPA_FX_SELECTOR_H

#include "Object.h"
#include "LadspaFXSelector_UI.h"
#include "LadspaFX.h"

#include "qstring.h"

class LadspaFXSelector : public LadspaFXSelector_UI, public Object
{
	Q_OBJECT

	public:
		LadspaFXSelector(int nLadspaFX);
		~LadspaFXSelector();

		string getSelectedFX();

		virtual void pluginSelected();
		virtual void groupSelected();

	private:
		string m_sSelectedPluginName;

		void buildLadspaGroups();
		void addGroup(QListViewItem *pItem, LadspaFXGroup *pGroup);

		vector<LadspaFXInfo*> findPluginsInGroup( string sSelectedGroup, LadspaFXGroup *pGroup );

};


#endif

==> hydrogen_0.9.1.orig.tar.gz: hydrogen-0.9.1/hydrogen_gui/LadspaFXSelector.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: LadspaFXSelector.h,v 1.6 2004/05/07 11:39:26 comix Exp $
 *
 */

#ifndef LADSPA_FX_SELECTOR_H
#define LADSPA_FX_SELECTOR_H

#include "Object.h"
#include "LadspaFXSelector_UI.h"

#include <string>
using std::string;
#include <vector>
using std::vector;


class LadspaFXInfo;
class LadspaFXGroup;

class LadspaFXSelector : public LadspaFXSelector_UI, public Object
{
	Q_OBJECT

	public:
		LadspaFXSelector(int nLadspaFX);
		~LadspaFXSelector();

		string getSelectedFX();

		virtual void pluginSelected();
		virtual void groupSelected();

	private:
		string m_sSelectedPluginName;

		void buildLadspaGroups();
		void addGroup(QListViewItem *pItem, LadspaFXGroup *pGroup);

		vector<LadspaFXInfo*> findPluginsInGroup( string sSelectedGroup, LadspaFXGroup *pGroup );

};


#endif
